@@ -27,18 +27,13 @@
 
 #include <stdio.h>
 
-#if HAVE_PTHREAD
+#ifdef HAVE_PTHREAD
 #include <pthread.h>
 #include <errno.h>
 #include <string.h>
 #include <stdio.h>
 #endif
 
-#if HAVE_INIT_ONCE
-#define _WIN32_WINNT 0x0600
-#include <windows.h>
-#endif
-
 /**
  * SECTION:graphene-vectors
  * @Title: Vectors
@@ -483,7 +478,7 @@ init_static_vec2_once (void)
   static_vec2[VEC2_Y_AXIS].value = graphene_simd4f_init (0.f, 1.f, 0.f, 0.f);
 }
 
-#if HAVE_PTHREAD
+#ifdef HAVE_PTHREAD
 static pthread_once_t static_vec2_once = PTHREAD_ONCE_INIT;
 
 static inline void
@@ -501,10 +496,10 @@ init_static_vec2 (void)
     }
 }
 
-#elif HAVE_INIT_ONCE
+#elif defined(HAVE_INIT_ONCE)
 static INIT_ONCE static_vec2_once = INIT_ONCE_STATIC_INIT;
 
-BOOL CALLBACK
+static BOOL CALLBACK
 InitVec2Func (PINIT_ONCE InitOnce,
               PVOID      Parameter,
               PVOID     *lpContext)
@@ -1164,7 +1159,7 @@ init_static_vec3_once (void)
   static_vec3[VEC3_Z_AXIS].value = graphene_simd4f_init (0.f, 0.f, 1.f, 0.f);
 }
 
-#if HAVE_PTHREAD
+#ifdef HAVE_PTHREAD
 static pthread_once_t static_vec3_once = PTHREAD_ONCE_INIT;
 
 static inline void
@@ -1182,10 +1177,10 @@ init_static_vec3 (void)
     }
 }
 
-#elif HAVE_INIT_ONCE
+#elif defined(HAVE_INIT_ONCE)
 static INIT_ONCE static_vec3_once = INIT_ONCE_STATIC_INIT;
 
-BOOL CALLBACK
+static BOOL CALLBACK
 InitVec3Func (PINIT_ONCE InitOnce,
               PVOID      Parameter,
               PVOID     *lpContext)
@@ -1863,7 +1858,7 @@ init_static_vec4_once (void)
   static_vec4[VEC4_W_AXIS].value = graphene_simd4f_init (0.f, 0.f, 0.f, 1.f);
 }
 
-#if HAVE_PTHREAD
+#ifdef HAVE_PTHREAD
 static pthread_once_t static_vec4_init_once = PTHREAD_ONCE_INIT;
 
 static inline void
@@ -1881,10 +1876,10 @@ init_static_vec4 (void)
     }
 }
 
-#elif HAVE_INIT_ONCE
+#elif defined(HAVE_INIT_ONCE)
 static INIT_ONCE static_vec4_once = INIT_ONCE_STATIC_INIT;
 
-BOOL CALLBACK
+static BOOL CALLBACK
 InitVec4Func (PINIT_ONCE InitOnce,
               PVOID      Parameter,
               PVOID     *lpContext)
